/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

extern unsigned int gsh_rows;
extern unsigned int gsh_row;

void
gsh_parse_arguments(int argc, char **argv)
{
 unsigned int counter;

 for (counter = 1; counter < (unsigned int)argc; counter++)
 {
  if (argv[counter][0] == '-')
  {
   gsh_handle_switch_arguments(argc, argv, &counter);
  }
  else
  {
   gsh_command_button(argv[counter]);
  }
 }
}

